A network object with a node attribute specifying the
level of each node
motifs
a list of motif identifiers which shall be counted, e.g.
list("1,2[I.C]")
lvl_attr
character vector specifying the vertex attribute name where
level information is stored in net
assume_sparse
whether the network shall be assumed to be sparse (for
optimization), default TRUE
omit_total_result
whether total results shall be omitted, default
FALSE
directed
whether the graph shall be treated as a directed graph. Per
default (NULL), this is determined automatically using the structure
of the provided network object
Value
data frame with a column containing motif identifier strings and one
column containing motif counts