Learn R Programming

motifr (version 1.0.0)

dummy_net: Three-level network dummy example

Description

A simple statnet network object based on dummy data.

Usage

dummy_net

Arguments

Format

Statnet network object with 60 nodes and 1035 edges on three levels. The network contains two variables to describe nodes/ vertices.

vertex.names

node labes

sesType

Categorical variable specifying network levels for every node (levels are 0,1 and 2)

...

Examples

Run this code
# NOT RUN {
plot_mnet(dummy_net)
# }

Run the code above in your browser using DataLab