Learn R Programming

motifr (version 1.0.0)

exemplify_motif: Returns an example for a motif found in a given network

Description

Returns an example for a motif found in a given network

Usage

exemplify_motif(net, motif, lvl_attr = "sesType", directed = NULL)

Arguments

net

network object

motif

motif identifier string for the motif

lvl_attr

character vector specifying the attribute name where level information is stored in net.

directed

whether the graph shall be treated as a directed graph. Per default (NULL), this is determined automatically using the structure of the provided network object

Value

vector of nodes in the motif

See Also

motifr::show_motif

Examples

Run this code
# NOT RUN {
exemplify_motif(ml_net, motif = "1,2[I.C]", directed = FALSE)
# }

Run the code above in your browser using DataLab