Learn R Programming

motifr (version 1.0.0)

ml_net: Two-level network example (wetlands management)

Description

A statnet network object based on empirical data about actors and their activities in a case study of Swiss wetlands management

Usage

ml_net

Arguments

Format

Statnet network object with 132 nodes and 566 edges on two levels. One network level contains actors, a second network level contains activities. Links between actors indicate collaboration among actors. Links between actors and activities indicate that an actor is active in a given activity. Links between activities indicate that the activities are causally interdependent. The network contains two variables to describe nodes/ vertices.

vertex.names

node labes

sesType

Binary variable specifying network levels for every node (1 = node is a social node (actor) , 0 = node is a non-social node (an activity))

...

Examples

Run this code
# NOT RUN {
plot_mnet(ml_net)
# }

Run the code above in your browser using DataLab