This function supports the Erd<U+0151>s-R<U+00E9>nyi Model (erdos_renyi) and the the
Actor<U+2019>s Choice Model (actors_choice). The model can be specified using
the model parameter. The Erd<U+0151>s-R<U+00E9>nyi Model can be used without
providing further parameters. In case of the Actor<U+2019>s Choice Model a level of
the given network can be specified which is only level assumed to be
variable. All other levels are assumed to be fixed. Per default, level
= -1, the first level carrying two nodes in the signature of the motif is
selected as variable level. Set the level parameter to the value of
the lvl_attr of the nodes in the desired level to specify the level
manually.
motifs_distribution(
net,
motifs,
lvl_attr = "sesType",
model = "erdos_renyi",
level = -1,
omit_total_result = TRUE,
directed = NULL
)network object
list of motif identifiers describing the motifs whose distribution shall be analysed
character vector specifying the attribute name where level
information is stored in net.
baseline model to be used. options are "erdos_renyi" and "actors_choice". Defaults to "erdos_renyi".
Additional parameter to set the level to vary for the actors_choice model manually. All other levels are held fixed.
whether total results shall be omitted
whether the graph shall be treated as a directed graph. Per
default (NULL), this is determined automatically using the structure
of the provided network object
data frame with one column giving names of motif identifers and two column giving expectation and variances per motif. For other motifs, expectations are computed but variances are returned as NaN.
# NOT RUN {
motifs_distribution(ml_net, motif = list("1,2[I.C]"), directed = FALSE)
# }
Run the code above in your browser using DataLab