character vector specifying the attribute name where level
information is stored in net.
directed
whether the graph shall be treated as a directed graph. Per
default (NULL), this is determined automatically using the structure
of the provided network object
...
additional arguments to be passed to plotting function (e.g.
label = TRUE)