Learn R Programming

motifr (version 1.0.0)

supported_signatures: Lists all supported signatures

Description

Returns a data frame with three columns: signature, a Boolean value indicating whether the motifs are directed, the number of levels which the motif spans across

Usage

supported_signatures()

Arguments

Value

data frame with all supported signatures

See Also

supported_classes()

Examples

Run this code
# NOT RUN {
supported_signatures()
# }

Run the code above in your browser using DataLab