powered by
A simple statnet network object based on dummy data.
dummy_net
Statnet network object with 60 nodes and 1035 edges on three levels. The network contains two variables to describe nodes/ vertices.
node labes
Categorical variable specifying network levels for every node (levels are 0,1 and 2)
# NOT RUN { plot_mnet(dummy_net) # }
Run the code above in your browser using DataLab