motif_summary: Summary for motif counts and Erd<U+0151>s-R<U+00E9>nyi distribution
Description
Returns a data frame with counts and statistical properties (expectation,
variances) of six selected motifs in the given network. Note that this
function implicitly assumes that the network is undirected, cf.
motifr::to_py_graph.
Usage
motif_summary(net, lvl_attr = c("sesType"))
Arguments
net
network object
lvl_attr
character vector specifying the attribute name where level
information is stored in net.
Value
dataframe with motif counts, expectations and variances for set of
selected motifs