Note that this only works for undirected graphs. Regardless of whether the input graph is directed it is treated as undirected graph.
plot_gaps_or_critical_dyads(
net,
edge_contribution,
colour,
title,
lvl_attr = c("sesType"),
cutoff = 2,
subset_graph = "none",
...
)network object
data frame providing edge contribution data
colour code for the weighted edges
title of the plot
nodal attribute specifying level information
Cut-off point in contributions of an edge to the number of motifs above which to analyse gaps
Whether to subset the graph to only show nodes involved in gaps. One of "none" (no subset, default), "partial" (only focal level is subset) or "focal" (only focal level shown)
list of additional parameters to be passed to plotting function
(see motifr::plot_mnet), e.g. label = TRUE
A plot of gaps or critical edges, sized by weight in a multilevel network
plot_gaps, plot_critical_dyads.