powered by
Returns a data frame with three columns: signature, a Boolean value indicating whether the motifs are directed, the number of levels which the motif spans across
supported_signatures()
data frame with all supported signatures
supported_classes()
# NOT RUN { supported_signatures() # }
Run the code above in your browser using DataLab